aboutsummaryrefslogtreecommitdiffstats
path: root/version_info.h
diff options
context:
space:
mode:
authorStig Bjørlykke <stig@bjorlykke.org>2010-10-21 07:13:43 +0000
committerStig Bjørlykke <stig@bjorlykke.org>2010-10-21 07:13:43 +0000
commit2cedc69849087c220c7d9f04c559e9824fde844d (patch)
tree26815d44b8853ef6cdd90ac777f4b1c569584a76 /version_info.h
parent5c18160006d1df99214d3a8d0fa30ebfeab7dda7 (diff)
Fixed "Compiled with" information in the About box.
svn path=/trunk/; revision=34601
Diffstat (limited to 'version_info.h')
-rw-r--r--version_info.h8
1 files changed, 6 insertions, 2 deletions
diff --git a/version_info.h b/version_info.h
index 71638f98d1..0d85d17a5b 100644
--- a/version_info.h
+++ b/version_info.h
@@ -39,13 +39,17 @@ extern const gchar *wireshark_svnversion;
* Get various library compile-time versions and append them to
* the specified GString.
*
* "additional_info" is called at the end to append any additional
* information; this is required in order to, for example, put the
* Portaudio information at the end of the string, as we currently
* don't use Portaudio in TShark.
*/
void get_compiled_version_info(GString *str,
- void (*additional_info)(GString *));
+ void (*prepend_info)(GString *),
+ void (*append_info)(GString *));
/*
* Get various library run-time versions, and the OS version, and append
@@ -39,13 +39,17 @@ extern const gchar *wireshark_svnversion;
* the specified GString.
*
- * "additional_info" is called at the end to append any additional
+ * "prepend_info" is called at the start to prepend any additional
+ * information.
+ *
+ * "append_info" is called at the end to append any additional
* information; this is required in order to, for example, put the
* Portaudio information at the end of the string, as we currently